package cfg

import (
	"cicv-data-closedloop/kinglong/common/log"
	"gopkg.in/yaml.v2"
	"os"
)

type localConfig struct {
	UrlGetOssConfig      string `yaml:"url-get-oss-config"`      // 获取oss配置的url
	OssBasePrefix        string `yaml:"oss-base-prefix"`         // 云端配置文件的位置
	EquipmentNo          string `yaml:"equipment-no"`            // 当前设备的编号
	CloudConfigFilename  string `yaml:"cloud-config-filename"`   // 云端配置文件名称
	CloudConfigLocalPath string `yaml:"cloud-config-local-path"` // 将 oss 的配置文件下载到本地的位置
	SecretKey            string `yaml:"secret-key"`              // 当前设备的密钥
	RestartDir           string `yaml:"restart-dir"`             // 重启命令执行的目录
	RestartCmd           string `yaml:"restart-cmd"`             // 重启命令
}

var (
	LocalConfig     localConfig
	localConfigPath = "/mnt/media/sda1/rosbag-handle/config/local-config.yaml"
)

func InitLocalConfig() {
	log.GlobalLogger.Info("初始化本地配置文件 - 开始：", localConfigPath)
	// 读取YAML文件内容
	content, err := os.ReadFile(localConfigPath)
	if err != nil {
		log.GlobalLogger.Error("读取本地配置文件失败。", err)
		os.Exit(-1)
	}

	// 解析YAML内容
	err = yaml.Unmarshal(content, &LocalConfig)
	if err != nil {
		log.GlobalLogger.Error("解析本地配置文件失败。", err)
		os.Exit(-1)
	}

	log.GlobalLogger.Info("初始化本地配置文件 - 成功：", LocalConfig)

}
